Directive

Enum Directive 

pub enum Directive {
    Orig(Offset<u16, 16>),
    Fill(PCOffset<u16, 16>),
    Blkw(Offset<u16, 16>),
    Stringz(String),
    End,
    External(Label),
}
An enum representing all the possible directives in LC-3 assembly code.

Variants



Orig(Offset<u16, 16>)

An .orig directive.

Operation

Starts a block of assembly.

Syntax

.orig ADDR



Fill(PCOffset<u16, 16>)

A .fill directive.

Operation

Writes some data into the given memory location.

Syntax

.fill DATA .fill LABEL



Blkw(Offset<u16, 16>)

A .blkw directive.

Operation

Saves a provided number of memory locations for writing into.

Syntax

.blkw N



Stringz(String)

A .stringz directive.

Operation

Writes a null-terminated string into the provided location.

Syntax

.stringz "A literal"



End

A .end directive.

Operation

Closes a block started by an .orig.

Syntax

.end



External(Label)

A .external directive.

Operation

Designates that a label is external, meaning it is not defined within the file and must be linked in.

Syntax

.external LABEL