Breakpoint

Enum Breakpoint 

pub enum Breakpoint {
    PC(u16),
    Reg {
        reg: Reg,
        value: Comparator,
    },
    Mem {
        addr: u16,
        value: Comparator,
    },
}
Common breakpoints.

Variants



PC(u16)

Break when the PC is equal to the given value.



Reg

Break when the provided register is set to a given value.

Fields

reg: Reg

Register to check.

value: Comparator

Predicate to break against.



Mem

Break when the provided memory address is written to with a given value.

Fields

addr: u16

Address to check.

value: Comparator

Predicate to break against.

Implementations

Source

impl Breakpoint

pub fn check(&self, sim: &Simulator) -> bool

Checks if a break should occur.