Handlers for external devices connected to the Simulator.
This handles IO devices (such as the keyboard and display) and handles interrupts.
The core types here are:
ExternalDevice: A device which can be connected to the Simulator.DeviceHandler: The handler for the Simulator’s IO ports & interrupts.
This module also provides some IO devices:
NullDevice: Does nothing.BufferedKeyboard: Keyboard device that reads off of an input buffer.BufferedDisplay: Display device that writes to an output buffer.TimerDevice: Timer that triggers an interrupt after a specified number of interrupts.
Structs
- Buffered
Display - A display that delegates its output to a buffer.
- Buffered
Keyboard - Keyboard that accesses input from a memory buffer.
- Device
Handler - The central hub for all external devices for the Simulator.
- External
Interrupt - An interrupt not handled by the simulator occurred.
- Interrupt
- An interrupt.
- Interrupt
From Fn - A device that handles interrupts with a function.
- Null
Device - Does nothing.
- Timer
Device - A timer device that triggers an interrupt after a configured number (or range) of instructions.
Traits
- External
Device - An external device, which can be accessed via memory-mapped IO or via interrupts.