pub trait Error: Error {
// Required method
fn help(&self) -> Option<Cow<'_, str>>;
// Provided method
fn span(&self) -> Option<ErrSpan> { ... }
}Expand description
Unified error interface for all errors in this crate.
Note that the Display implementation is used for a brief message,
where as Error::help is used for any clarifying messages.
Required Methods
Provided Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".