Simple to parse components.
This module holds components that are very simple to parse (defined as only requiring a single token and no additional state from the parser).
The key type of this module is the TokenParse trait which defines
how to “simply parse” a component.
See that trait for more details about its utility over Parse.
This module also provides several utility parsers (e.g., Comma and Colon)
for use in more complex component parsing.
Structs
- Colon
- Colon.
- Comma
- Comma.
- End
- The end of a line or input.
- IntLiteral
- An (signed or unsigned) int literal.
This is primarily only used for
.fill, which is sign-agnostic. - StrLiteral
- A string literal.
Enums
- Either
- Either one component or another.
Traits
- Token
Parse - Components that can be constructed with a single token and require no additional parser state.