Module device

Module device 

Handlers for external devices connected to the Simulator.

This handles IO devices (such as the keyboard and display) and handles interrupts.

The core types here are:

  • ExternalDevice: A device which can be connected to the Simulator.
  • DeviceHandler: The handler for the Simulator’s IO ports & interrupts.

This module also provides some IO devices:

Structs

BufferedDisplay
A display that delegates its output to a buffer.
BufferedKeyboard
Keyboard that accesses input from a memory buffer.
DeviceHandler
The central hub for all external devices for the Simulator.
ExternalInterrupt
An interrupt not handled by the simulator occurred.
Interrupt
An interrupt.
InterruptFromFn
A device that handles interrupts with a function.
NullDevice
Does nothing.
TimerDevice
A timer device that triggers an interrupt after a configured number (or range) of instructions.

Traits

ExternalDevice
An external device, which can be accessed via memory-mapped IO or via interrupts.